class
	LIBMONGO_DEMO

inherit
	ARGUMENTS
	CE_UTILITIES

create
	make

feature {NONE}

	make
		local
			l_host: STRING_8
			l_db: PD_MONGO
			l_failed: BOOLEAN
		do
			if argument_count >= 1 then
				l_host := argument (1)
			else
				l_host := "127.0.0.1"
			end

			create l_db.make
			l_db.init_sockets
			l_failed := l_db.connect (ce_string (l_host), 27017).to_boolean
			if l_failed then
				-- error codes are in `PC_MONGO_ERROR_T'
				Io.error.put_string ("Connecting failed (" + l_db.err.out +"): " + eif_string (l_db.errstr) + "%N")
			else
				add_data_to_database (l_db)
				print_database_contents (l_db)
				l_db.destroy
			end
		end

feature {NONE}

	Mongo_ok: INTEGER_32 = 0

feature {NONE}

	add_data_to_database (a_db: PD_MONGO)
		local
			l_done: BOOLEAN
			l_name: STRING_8
			l_age: INTEGER_32
			l_bson: PD_BSON
			l_custom_write_concern: CE_POINTER [PD_MONGO_WRITE_CONCERN]
		do
			from
				create {CE_CLASS_POINTER [PD_MONGO_WRITE_CONCERN]} l_custom_write_concern.make
			until
				l_done
			loop
				Io.put_string ("Want to add a person to the database? [y|n] ")
				Io.read_line
				if Io.last_string.is_equal ("y") then
					Io.put_string ("Name: ")
					Io.read_line
					l_name := Io.last_string.twin
					Io.put_string ("Age: ")
					Io.read_line
					l_age := Io.last_string.to_integer_32

					create l_bson.make
					l_bson.init
					l_bson.append_new_oid (ce_string ("_id")).do_nothing
					l_bson.append_string (ce_string ("name"), ce_string (l_name)).do_nothing
					l_bson.append_int (ce_string ("age"), l_age).do_nothing
					l_bson.finish.do_nothing
					a_db.insert (ce_string ("tutorial.people"), l_bson.address, l_custom_write_concern).do_nothing
					l_bson.destroy
				else
					l_done := True
				end
			end
		end

	print_database_contents (a_db: PD_MONGO)
		local
			l_cursor: PD_MONGO_CURSOR
		do
			Io.put_string ("Database contents:%N")
			from
				create l_cursor.make
				l_cursor.init (a_db.address, ce_string ("tutorial.people"))
			until
				l_cursor.next /= Mongo_ok
			loop
				l_cursor.current2.print2
			end
			l_cursor.destroy.do_nothing
		end

end
